@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-use Test::More tests => 8;
+use Test::More tests => 9;
 
 BEGIN { $| = 1; }
 use_ok(Digest::CRC, qw(crc32 crc16 crcccitt));
@@ -41,3 +41,10 @@ $ctx = Digest::CRC->new(width=>16,init=>0,xorout=>0,poly=>0x3456,
                         refin=>1,refout=>1);
 $ctx->add($input);
 ok($ctx->digest == 12803, 'OO crc16 poly 3456'); 
+
+# crc8 test from Mathis Moder <mathis@pixelconcepts.de>
+$ctx = Digest::CRC->new(width=>8, init=>0xab, xorout=>0x00,poly=>0x07,
+                        refin=>0, refout=>0);
+$ctx->add($input);
+ok($ctx->digest == 135, 'OO crc8 poly 07');
+
